Package: regutools
Title: regutools: an R package for data extraction from RegulonDB
Version: 1.22.0
Date: 2021-11-15
Authors@R: c(
    person ("Joselyn", "Chavez", email =  "joselynchavezf@gmail.com",
        role = c("aut", "cre"), comment = c(ORCID = "0000-0002-4974-4591")),
    person("Carmina", "Barberena-Jonas", email = "car.barjon@gmail.com",
        role = c("aut"), comment = c(ORCID = "0000-0001-7413-638X")),
    person(c("Jesus", "E."), "Sotelo-Fonseca", email = "jemilianosf@gmail.com",
        role = c("aut"), comment = c(ORCID = "0000-0003-1600-2396")),
    person("Jose", "Alquicira-Hernandez", email = "joseah@lcg.unam.mx",
        role = c("ctb"), comment = c(ORCID = "0000-0002-9049-7780")),
    person("Heladia", "Salgado", email = "heladia@ccg.unam.mx",
        role = c("ctb"), comment = c(ORCID = "0000-0002-3166-5801")),
    person("Leonardo", "Collado-Torres", role = c("aut"),
        email = "lcolladotor@gmail.com",
        comment = c(ORCID = "0000-0003-2140-308X")),
    person("Alejandro", "Reyes", email = "alejandro.reyes.ds@gmail.com",
        role = c("aut"), comment = c(ORCID = "0000-0001-8717-6612"))
    )
Description: RegulonDB has collected, harmonized and centralized data 
    from hundreds of experiments for nearly two decades and is considered
    a point of reference for transcriptional regulation in Escherichia coli K12. 
    Here, we present the regutools R package to facilitate programmatic 
    access to RegulonDB data in computational biology. regutools provides 
    researchers with the possibility of writing reproducible workflows 
    with automated queries to RegulonDB. The regutools package serves as
    a bridge between RegulonDB data and the Bioconductor ecosystem by 
    reusing the data structures and statistical methods powered by other 
    Bioconductor packages. We demonstrate the integration of regutools 
    with Bioconductor by analyzing transcription factor DNA binding sites 
    and transcriptional regulatory networks from RegulonDB. We anticipate 
    that regutools will serve as a useful building block in our progress
    to further our understanding of gene regulatory networks.
License: Artistic-2.0
Encoding: UTF-8
Depends: R (>= 4.0)
Imports: AnnotationDbi, AnnotationHub, Biostrings, DBI, GenomicRanges,
        Gviz, IRanges, RCy3, RSQLite, S4Vectors, methods, stats, utils,
        BiocFileCache
RoxygenNote: 7.1.1
Suggests: BiocStyle, knitr, RefManageR, rmarkdown, sessioninfo,
        testthat (>= 2.1.0), covr
URL: https://github.com/ComunidadBioInfo/regutools
BugReports: https://support.bioconductor.org/t/regutools
biocViews: GeneRegulation, GeneExpression, SystemsBiology,
        Network,NetworkInference,Visualization, Transcription
Roxygen: list(markdown = TRUE)
VignetteBuilder: knitr
git_url: https://git.bioconductor.org/packages/regutools
git_branch: RELEASE_3_22
git_last_commit: f94aecc
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-10-29
NeedsCompilation: no
Packaged: 2025-10-30 06:01:45 UTC; biocbuild
Author: Joselyn Chavez [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-4974-4591>),
  Carmina Barberena-Jonas [aut] (ORCID:
    <https://orcid.org/0000-0001-7413-638X>),
  Jesus E. Sotelo-Fonseca [aut] (ORCID:
    <https://orcid.org/0000-0003-1600-2396>),
  Jose Alquicira-Hernandez [ctb] (ORCID:
    <https://orcid.org/0000-0002-9049-7780>),
  Heladia Salgado [ctb] (ORCID: <https://orcid.org/0000-0002-3166-5801>),
  Leonardo Collado-Torres [aut] (ORCID:
    <https://orcid.org/0000-0003-2140-308X>),
  Alejandro Reyes [aut] (ORCID: <https://orcid.org/0000-0001-8717-6612>)
Maintainer: Joselyn Chavez <joselynchavezf@gmail.com>
